@@ -80,5 +80,5 @@ class Asset(Task, CodeMixin):
     def __hash__(self):
         """the overridden __hash__ method
         """
-        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+        return super(Asset, self).__hash__()
 
