@@ -222,7 +222,7 @@ class Shot(Task, CodeMixin):
     def __hash__(self):
         """the overridden __hash__ method
         """
-        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+        return super(Shot, self).__hash__()
 
     def _check_code_availability(self, code, project):
         """checks if the given code is available in the given project
