@@ -19,20 +19,20 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 import datetime
-import unittest2
+import unittest
 
 from stalker import log
 from stalker.db.session import DBSession
 from stalker import (db, Asset, Entity, ImageFormat, Link, Project, Repository,
                      Sequence, Shot, Status, StatusList, Structure, Task, Type,
-                     User, Ticket)
+                     User, Ticket, Client)
 import logging
 
 logger = logging.getLogger('stalker.models.project')
 logger.setLevel(log.logging_level)
 
 
-class ProjectTestCase(unittest2.TestCase):
+class ProjectTestCase(unittest.TestCase):
     """tests the Project class
     """
 
@@ -140,6 +140,13 @@ class ProjectTestCase(unittest2.TestCase):
             password="123456"
         )
 
+        self.test_user_client = User(
+            name="User Client",
+            login="userClient",
+            email="user@client.com",
+            password="123456"
+        )
+
         # statuses
         self.status_new = Status(name="New", code="NEW")
         self.status_wfd = Status(name="Waiting For Dependency", code="WFD")
@@ -209,6 +216,11 @@ class ProjectTestCase(unittest2.TestCase):
             name="Commercials Repository",
         )
 
+        self.test_client = Client(
+            name='Test Company',
+            users=[self.test_user_client]
+        )
+
         # create a project object
         self.kwargs = {
             "name": "Test Project",
@@ -224,7 +236,8 @@ class ProjectTestCase(unittest2.TestCase):
             "display_width": 15,
             "start": self.start,
             "end": self.end,
-            "status_list": self.project_status_list
+            "status_list": self.project_status_list,
+            "client": self.test_client
         }
 
         self.test_project = Project(**self.kwargs)
@@ -693,8 +706,8 @@ class ProjectTestCase(unittest2.TestCase):
     def test_setup_is_working_correctly(self):
         """testing if the setup is done correctly
         """
-        self.assertIsInstance(self.test_project_type, Type)
-        self.assertIsInstance(self.test_project_type2, Type)
+        self.assertTrue(isinstance(self.test_project_type, Type))
+        self.assertTrue(isinstance(self.test_project_type2, Type))
 
     def test_lead_argument_is_given_as_None(self):
         """testing if no error will be raised when the lead arguments is given
@@ -702,7 +715,7 @@ class ProjectTestCase(unittest2.TestCase):
         """
         self.kwargs["lead"] = None
         new_project = Project(**self.kwargs)
-        self.assertIsInstance(new_project, Project)
+        self.assertTrue(isinstance(new_project, Project))
 
     def test_lead_attribute_is_set_to_None(self):
         """testing if no error will be raised when the lead attribute is set to
@@ -790,7 +803,7 @@ class ProjectTestCase(unittest2.TestCase):
         # and a proper image format
         self.kwargs["image_format"] = self.test_image_format
         new_project = Project(**self.kwargs)
-        self.assertIsInstance(new_project, Project)
+        self.assertTrue(isinstance(new_project, Project))
 
     def test_image_format_attribute_accepts_ImageFormat_only(self):
         """testing if a TypeError will be raised when the image_format
@@ -908,7 +921,7 @@ class ProjectTestCase(unittest2.TestCase):
         test_value = 1
         self.kwargs["fps"] = test_value
         new_project = Project(**self.kwargs)
-        self.assertIsInstance(new_project.fps, float)
+        self.assertTrue(isinstance(new_project.fps, float))
         self.assertEqual(new_project.fps, float(test_value))
 
     def test_fps_attribute_float_conversion_2(self):
@@ -917,7 +930,7 @@ class ProjectTestCase(unittest2.TestCase):
         """
         test_value = 1
         self.test_project.fps = test_value
-        self.assertIsInstance(self.test_project.fps, float)
+        self.assertTrue(isinstance(self.test_project.fps, float))
         self.assertEqual(self.test_project.fps, float(test_value))
 
     def test_fps_argument_is_zero(self):
@@ -1015,7 +1028,7 @@ class ProjectTestCase(unittest2.TestCase):
         """
         self.kwargs["structure"] = None
         new_project = Project(**self.kwargs)
-        self.assertIsInstance(new_project, Project)
+        self.assertTrue(isinstance(new_project, Project))
 
     def test_structure_attribute_is_None(self):
         """testing if nothing happens when the structure attribute is set to
@@ -1284,7 +1297,10 @@ class ProjectTestCase(unittest2.TestCase):
                                 self.test_user2,
                                 self.test_user3]
         new_proj = Project(**self.kwargs)
-        self.assertItemsEqual(self.kwargs['users'], new_proj.users)
+        self.assertEqual(
+            sorted(self.kwargs['users'], key=lambda x: x.name),
+            sorted(new_proj.users, key=lambda x: x.name)
+        )
 
     def test_users_attribute_is_working_properly(self):
         """testing if the users attribute is working properly
@@ -1293,7 +1309,10 @@ class ProjectTestCase(unittest2.TestCase):
                  self.test_user2,
                  self.test_user3]
         self.test_project.users = users
-        self.assertItemsEqual(users, self.test_project.users)
+        self.assertEqual(
+            sorted(users, key=lambda x: x.name),
+            sorted(self.test_project.users, key=lambda x: x.name)
+        )
 
     def test_tjp_id_is_working_properly(self):
         """testing if the tjp_id attribute is working properly
@@ -1307,326 +1326,382 @@ class ProjectTestCase(unittest2.TestCase):
         from jinja2 import Template
 
         expected_tjp_temp = Template("""
-task Project_33 "Test Project" {
+task Project_{{project.id}} "Test Project" {
         
-task Sequence_34 "Seq1" {
+task Sequence_{{sequence1.id}} "Seq1" {
 
     
             
             
             effort 1.0h
-            allocate User_1             
+            allocate User_{{user1.id}}             
 }        
-task Sequence_35 "Seq2" {
+task Sequence_{{sequence2.id}} "Seq2" {
 
     
             
             
             effort 1.0h
-            allocate User_12             
+            allocate User_{{user2.id}}             
 }        
-task Sequence_36 "Seq3" {
+task Sequence_{{sequence3.id}} "Seq3" {
 
     
             
             
             effort 1.0h
-            allocate User_13             
+            allocate User_{{user3.id}}             
 }        
-task Sequence_37 "Seq4" {
+task Sequence_{{sequence4.id}} "Seq4" {
 
     
     
-task Task_53 "Test Task 4" {
+task Task_{{task4.id}} "Test Task 4" {
 
     
             
             
             effort 1.0h
-            allocate User_19             
+            allocate User_{{user4.id}}             
 }
-task Task_54 "Test Task 5" {
+task Task_{{task5.id}} "Test Task 5" {
 
     
             
             
             effort 1.0h
-            allocate User_20             
+            allocate User_{{user5.id}}             
 }
-task Task_55 "Test Task 6" {
+task Task_{{task6.id}} "Test Task 6" {
 
     
             
             
             effort 1.0h
-            allocate User_21             
+            allocate User_{{user6.id}}             
 }
 }        
-task Sequence_38 "Seq5" {
+task Sequence_{{sequence5.id}} "Seq5" {
 
     
     
-task Task_56 "Test Task 7" {
+task Task_{{task7.id}} "Test Task 7" {
 
     
             
             
             effort 1.0h
-            allocate User_22             
+            allocate User_{{user7.id}}             
 }
-task Task_57 "Test Task 8" {
+task Task_{{task8.id}} "Test Task 8" {
 
     
             
             
             effort 1.0h
-            allocate User_23             
+            allocate User_{{user8.id}}             
 }
-task Task_58 "Test Task 9" {
+task Task_{{task9.id}} "Test Task 9" {
 
     
             
             
             effort 1.0h
-            allocate User_24             
+            allocate User_{{user9.id}}             
 }
 }        
-task Sequence_39 "Seq6" {
+task Sequence_{{sequence6.id}} "Seq6" {
 
     
                         
 }        
-task Sequence_40 "Seq7" {
+task Sequence_{{sequence7.id}} "Seq7" {
 
     
                         
 }        
-task Shot_41 "{{shot1.name}}" {
+task Shot_{{shot1.id}} "{{shot1.name}}" {
 
     
     
-task Task_59 "Test Task 10" {
+task Task_{{task10.id}} "Test Task 10" {
 
     
             
             
             effort 10.0h
-            allocate User_25             
+            allocate User_{{user10.id}}             
 }
-task Task_60 "Test Task 11" {
+task Task_{{task11.id}} "Test Task 11" {
 
     
             
             
             effort 1.0h
-            allocate User_1 , User_12             
+            allocate User_{{user1.id}} , User_{{user2.id}}             
 }
-task Task_61 "Test Task 12" {
+task Task_{{task12.id}} "Test Task 12" {
 
     
             
             
             effort 1.0h
-            allocate User_13 , User_19             
+            allocate User_{{user3.id}} , User_{{user4.id}}             
 }
 }        
-task Shot_42 "{{shot2.name}}" {
+task Shot_{{shot2.id}} "{{shot2.name}}" {
 
     
     
-task Task_62 "Test Task 13" {
+task Task_{{task13.id}} "Test Task 13" {
 
     
             
             
             effort 1.0h
-            allocate User_20 , User_21             
+            allocate User_{{user5.id}} , User_{{user6.id}}             
 }
-task Task_63 "Test Task 14" {
+task Task_{{task14.id}} "Test Task 14" {
 
     
             
             
             effort 1.0h
-            allocate User_22 , User_23             
+            allocate User_{{user7.id}} , User_{{user8.id}}             
 }
-task Task_64 "Test Task 15" {
+task Task_{{task15.id}} "Test Task 15" {
 
     
             
             
             effort 1.0h
-            allocate User_24 , User_25             
+            allocate User_{{user9.id}} , User_{{user10.id}}             
 }
 }        
-task Shot_43 "{{shot3.name}}" {
+task Shot_{{shot3.id}} "{{shot3.name}}" {
 
     
     
-task Task_65 "Test Task 16" {
+task Task_{{task16.id}} "Test Task 16" {
 
     
             
             
             effort 1.0h
-            allocate User_1 , User_12 , User_13             
+            allocate User_{{user1.id}} , User_{{user2.id}} , User_{{user3.id}}             
 }
-task Task_66 "Test Task 17" {
+task Task_{{task17.id}} "Test Task 17" {
 
     
             
             
             effort 1.0h
-            allocate User_19 , User_20 , User_21             
+            allocate User_{{user4.id}} , User_{{user5.id}} , User_{{user6.id}}             
 }
-task Task_67 "Test Task 18" {
+task Task_{{task18.id}} "Test Task 18" {
 
     
             
             
             effort 1.0h
-            allocate User_22 , User_23 , User_24             
+            allocate User_{{user7.id}} , User_{{user8.id}} , User_{{user9.id}}             
 }
 }        
-task Shot_44 "{{shot4.name}}" {
+task Shot_{{shot4.id}} "{{shot4.name}}" {
 
     
     
-task Task_68 "Test Task 19" {
+task Task_{{task19.id}} "Test Task 19" {
 
     
             
             
             effort 1.0h
-            allocate User_1 , User_12 , User_25             
+            allocate User_{{user1.id}} , User_{{user2.id}} , User_{{user10.id}}             
 }
-task Task_69 "Test Task 20" {
+task Task_{{task20.id}} "Test Task 20" {
 
     
             
             
             effort 1.0h
-            allocate User_13 , User_19 , User_20             
+            allocate User_{{user3.id}} , User_{{user4.id}} , User_{{user5.id}}             
 }
-task Task_70 "Test Task 21" {
+task Task_{{task21.id}} "Test Task 21" {
 
     
             
             
             effort 1.0h
-            allocate User_21 , User_22 , User_23             
+            allocate User_{{user6.id}} , User_{{user7.id}} , User_{{user8.id}}             
 }
 }        
-task Asset_45 "Test Asset 1" {
+task Asset_{{asset1.id}} "Test Asset 1" {
 
     
             
             
             effort 1.0h
-            allocate User_12             
+            allocate User_{{user2.id}}             
 }        
-task Asset_46 "Test Asset 2" {
+task Asset_{{asset2.id}} "Test Asset 2" {
 
     
                         
 }        
-task Asset_47 "Test Asset 3" {
+task Asset_{{asset3.id}} "Test Asset 3" {
 
     
                         
 }        
-task Asset_48 "Test Asset 4" {
+task Asset_{{asset4.id}} "Test Asset 4" {
 
     
     
-task Task_71 "Test Task 22" {
+task Task_{{task22.id}} "Test Task 22" {
 
     
             
             
             effort 1.0h
-            allocate User_1 , User_24 , User_25             
+            allocate User_{{user1.id}} , User_{{user9.id}} , User_{{user10.id}}             
 }
-task Task_72 "Test Task 23" {
+task Task_{{task23.id}} "Test Task 23" {
 
     
             
             
             effort 1.0h
-            allocate User_12 , User_13             
+            allocate User_{{user2.id}} , User_{{user3.id}}             
 }
-task Task_73 "Test Task 24" {
+task Task_{{task24.id}} "Test Task 24" {
 
     
             
             
             effort 1.0h
-            allocate User_19 , User_20             
+            allocate User_{{user4.id}} , User_{{user5.id}}             
 }
 }        
-task Asset_49 "Test Asset 5" {
+task Asset_{{asset5.id}} "Test Asset 5" {
 
     
     
-task Task_74 "Test Task 25" {
+task Task_{{task25.id}} "Test Task 25" {
 
     
             
             
             effort 1.0h
-            allocate User_21 , User_22             
+            allocate User_{{user6.id}} , User_{{user7.id}}             
 }
-task Task_75 "Test Task 26" {
+task Task_{{task26.id}} "Test Task 26" {
 
     
             
             
             effort 1.0h
-            allocate User_23 , User_24             
+            allocate User_{{user8.id}} , User_{{user9.id}}             
 }
-task Task_76 "Test Task 27" {
+task Task_{{task27.id}} "Test Task 27" {
 
     
             
             
             effort 1.0h
-            allocate User_1 , User_25             
+            allocate User_{{user1.id}} , User_{{user10.id}}             
 }
 }        
-task Task_50 "Test Task 1" {
+task Task_{{task1.id}} "Test Task 1" {
 
     
             
             
             effort 1.0h
-            allocate User_1             
+            allocate User_{{user1.id}}             
 }        
-task Task_51 "Test Task 2" {
+task Task_{{task2.id}} "Test Task 2" {
 
     
             
             
             effort 1.0h
-            allocate User_12             
+            allocate User_{{user2.id}}             
 }        
-task Task_52 "Test Task 3" {
+task Task_{{task3.id}} "Test Task 3" {
 
     
             
             
             effort 1.0h
-            allocate User_13             
+            allocate User_{{user3.id}}             
 }}""")
         expected_tjp = expected_tjp_temp.render({
+            'project': self.test_project,
+
+            'task1': self.test_task1,
+            'task2': self.test_task2,
+            'task3': self.test_task3,
+            'task4': self.test_task4,
+            'task5': self.test_task5,
+            'task6': self.test_task6,
+            'task7': self.test_task7,
+            'task8': self.test_task8,
+            'task9': self.test_task9,
+            'task10': self.test_task10,
+            'task11': self.test_task11,
+            'task12': self.test_task12,
+            'task13': self.test_task13,
+            'task14': self.test_task14,
+            'task15': self.test_task15,
+            'task16': self.test_task16,
+            'task17': self.test_task17,
+            'task18': self.test_task18,
+            'task19': self.test_task19,
+            'task20': self.test_task20,
+            'task21': self.test_task21,
+            'task22': self.test_task22,
+            'task23': self.test_task23,
+            'task24': self.test_task24,
+            'task25': self.test_task25,
+            'task26': self.test_task26,
+            'task27': self.test_task27,
+
+            'asset1': self.test_asset1,
+            'asset2': self.test_asset2,
+            'asset3': self.test_asset3,
+            'asset4': self.test_asset4,
+            'asset5': self.test_asset5,
+
             'shot1': self.test_shot1,
             'shot2': self.test_shot2,
             'shot3': self.test_shot3,
-            'shot4': self.test_shot4
+            'shot4': self.test_shot4,
+
+            'sequence1': self.test_seq1,
+            'sequence2': self.test_seq2,
+            'sequence3': self.test_seq3,
+            'sequence4': self.test_seq4,
+            'sequence5': self.test_seq5,
+            'sequence6': self.test_seq6,
+            'sequence7': self.test_seq7,
+
+            'user1': self.test_user1,
+            'user2': self.test_user2,
+            'user3': self.test_user3,
+            'user4': self.test_user4,
+            'user5': self.test_user5,
+            'user6': self.test_user6,
+            'user7': self.test_user7,
+            'user8': self.test_user8,
+            'user9': self.test_user9,
+            'user10': self.test_user10,
         })
 
         # print expected_tjp
         # print "-----------------"
-        print self.test_project.to_tjp
+        # print self.test_project.to_tjp
+        # self.maxDiff = None
 
         self.assertEqual(self.test_project.to_tjp, expected_tjp)
 
@@ -1812,8 +1887,77 @@ task Task_52 "Test Task 3" {
         self.assertEqual(self.test_project.percent_complete,
                          (1.0 / 44.0 * 100))
 
+    def test_client_argument_is_skipped(self):
+        """testing if the client attribute will be set to None when the client
+        argument is skipped
+        """
+        self.kwargs['name'] = 'New Project Name'
+        try:
+            self.kwargs.pop('client')
+        except KeyError:
+            pass
+        new_project = Project(**self.kwargs)
+        self.assertEquals(new_project.client, None)
 
-class ProjectTicketsTestCase(unittest2.TestCase):
+    def test_client_argument_is_None(self):
+        """testing if the client argument can be None
+        """
+        self.kwargs['client'] = None
+        new_project = Project(**self.kwargs)
+        self.assertIsNone(new_project.client)
+
+    def test_client_attribute_is_set_to_None(self):
+        """testing if it is possible to set the client attribute to None
+        """
+        self.assertIsNotNone(self.test_project.client)
+        self.test_project.client = None
+        self.assertIsNone(self.test_project.client)
+
+    def test_client_argument_is_given_as_something_other_than_a_client(self):
+        """testing if a TypeError will be raised when the client argument is
+        given as something other than a Client object
+        """
+        test_values = [1, 1.2, "a user", ["a", "user"], {"a": "user"}]
+
+        for test_value in test_values:
+            self.kwargs["client"] = test_value
+            self.assertRaises(
+                TypeError,
+                Project,
+                **self.kwargs
+            )
+
+    def test_client_attribute_is_not_a_client_instance(self):
+        """testing if a TypeError will be raised when the client attribute is
+        set to a value other than a Client instance
+        """
+        test_values = [1, 1.2, "a user", ["a", "user"], {"a": "user"}]
+
+        for test_value in test_values:
+            self.assertRaises(
+                TypeError,
+                setattr,
+                self.test_project,
+                'client',
+                test_value
+            )
+
+    def test_client_argument_is_working_properly(self):
+        """testing if the client argument value is correctly passed to the
+        client attribute
+        """
+        self.assertEqual(self.test_project.client, self.kwargs['client'])
+
+    def test_client_attribute_is_working_properly(self):
+        """testing if the client attribute value can be updated correctly
+        """
+        new_client = Client(name='New Client')
+        self.assertNotEqual(self.test_project.client, new_client)
+        self.test_project.client = new_client
+        self.assertEqual(self.test_project.client, new_client)
+
+
+class ProjectTicketsTestCase(unittest.TestCase):
     """tests the Project <-> Ticket relation
     """
 
@@ -2118,11 +2262,13 @@ class ProjectTicketsTestCase(unittest2.TestCase):
         self.assertTrue(len(self.test_project.tickets) > 0)
 
         # now check for exact items
-        self.assertItemsEqual(
-            self.test_project.tickets,
-            [self.test_ticket1, self.test_ticket2, self.test_ticket3,
-             self.test_ticket4, self.test_ticket5, self.test_ticket6,
-             self.test_ticket7, self.test_ticket8, self.test_ticket9]
+        self.assertEqual(
+            sorted(self.test_project.tickets, key=lambda x: x.name),
+            sorted([
+                self.test_ticket1, self.test_ticket2, self.test_ticket3,
+                self.test_ticket4, self.test_ticket5, self.test_ticket6,
+                self.test_ticket7, self.test_ticket8, self.test_ticket9
+            ], key=lambda x: x.name)
         )
 
     def test_open_tickets_attribute_returns_all_open_tickets_owned_by_this_user(self):
@@ -2156,9 +2302,9 @@ class ProjectTicketsTestCase(unittest2.TestCase):
         self.assertTrue(len(self.test_project.open_tickets) > 0)
 
         # now check for exact items
-        self.assertItemsEqual(
-            self.test_project.open_tickets,
-            [
+        self.assertEqual(
+            sorted(self.test_project.open_tickets, key=lambda x: x.name),
+            sorted([
                 self.test_ticket1,
                 self.test_ticket2,
                 self.test_ticket3,
@@ -2167,7 +2313,7 @@ class ProjectTicketsTestCase(unittest2.TestCase):
                 self.test_ticket6,
                 self.test_ticket7,
                 self.test_ticket8
-            ]
+            ], key=lambda x: x.name)
         )
 
         # close a couple of them
@@ -2178,13 +2324,13 @@ class ProjectTicketsTestCase(unittest2.TestCase):
         self.test_ticket3.resolve(self.test_user1, CANTFIX)
 
         # new check again
-        self.assertItemsEqual(
-            self.test_project.open_tickets,
-            [
+        self.assertEqual(
+            sorted(self.test_project.open_tickets, key=lambda x: x.name),
+            sorted([
                 self.test_ticket4,
                 self.test_ticket5,
                 self.test_ticket6,
                 self.test_ticket7,
                 self.test_ticket8
-            ]
+            ], key=lambda x: x.name)
         )
